@@ -2,7 +2,7 @@ package ExtUtils::ParseXS::Eval;
 use strict;
 use warnings;
 
-our $VERSION = '3.30';
+our $VERSION = '3.53';
 
 =head1 NAME
 
@@ -29,7 +29,7 @@ Warns the contents of C<$@> if any.
 Not all these variables are necessarily considered "public" wrt. use in
 typemaps, so beware. Variables set up from the ExtUtils::ParseXS object:
 
-  $Package $Alias $func_name $Full_func_name $pname
+  $Package $ALIAS $func_name $Full_func_name $pname
 
 Variables set up from C<$other_hashref>:
 
@@ -41,7 +41,8 @@ sub eval_output_typemap_code {
   my ($_pxs, $_code, $_other) = @_;
 
   my ($Package, $ALIAS, $func_name, $Full_func_name, $pname)
-    = @{$_pxs}{qw(Package ALIAS func_name Full_func_name pname)};
+    = @{$_pxs}{qw(PACKAGE_name xsub_seen_ALIAS xsub_func_name
+                  xsub_func_full_C_name xsub_func_full_perl_name)};
 
   my ($var, $type, $ntype, $subtype, $arg)
     = @{$_other}{qw(var type ntype subtype arg)};
@@ -63,7 +64,7 @@ Warns the contents of C<$@> if any.
 Not all these variables are necessarily considered "public" wrt. use in
 typemaps, so beware. Variables set up from the ExtUtils::ParseXS object:
 
-  $Package $Alias $func_name $Full_func_name $pname
+  $Package $ALIAS $func_name $Full_func_name $pname
 
 Variables set up from C<$other_hashref>:
 
@@ -75,7 +76,8 @@ sub eval_input_typemap_code {
   my ($_pxs, $_code, $_other) = @_;
 
   my ($Package, $ALIAS, $func_name, $Full_func_name, $pname)
-    = @{$_pxs}{qw(Package ALIAS func_name Full_func_name pname)};
+    = @{$_pxs}{qw(PACKAGE_name xsub_seen_ALIAS xsub_func_name
+                  xsub_func_full_C_name xsub_func_full_perl_name)};
 
   my ($var, $type, $num, $init, $printed_name, $arg, $ntype, $argoff, $subtype)
     = @{$_other}{qw(var type num init printed_name arg ntype argoff subtype)};
